==> haskell-hw-hspec-hedgehog-0.1.1.1-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-FEopFu23icL8wJXUACDxU6
key:                  hw-hspec-hedgehog-0.1.1.1-FEopFu23icL8wJXUACDxU6
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  42d48774ce6195a8ff34b8e94f8d60bb
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-FEopFu23icL8wJXUACDxU6
depends:
    HUnit-1.6.2.0-GKiTSh1k9RGH7VwfovEmUb base-4.17.2.1
    call-stack-0.4.0-4pWd6ELMFCA3tBa09iXezZ
    hedgehog-1.5-1wADOPSzGHCIXyZ68x9QuE
    hspec-2.11.2-EAjc0FWNx7lAkrkEnSI1Wl transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-hspec-hedgehog-0.1.1.1-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-7bM5LUJ7xkDCb47Ir24rOZ
key:                  hw-hspec-hedgehog-0.1.1.1-7bM5LUJ7xkDCb47Ir24rOZ
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  89b41318086613693038ade6bb5a2be1
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-7bM5LUJ7xkDCb47Ir24rOZ
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hedgehog-1.5-26x9IujI7098EA01VfGzc
    hspec-2.11.2-LoCWuRZ7Zs25PpiBaqPRLG transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
